@@ -63,8 +63,8 @@ test_that("match_spec() returns correct structure with AI", {
   skip_on_cran()
   skip_if_offline(host = "api.osf.io")
 
-  get_lib("model", path = tmp)
-  lib <- load_lib(type = "model", path = tmp)
+  get_lib("model_derivative", path = tmp)
+  lib <- load_lib(type = "model_derivative", path = tmp)
 
   check_OpenSpecy(lib) |>
     expect_error() |> expect_warning() |> expect_warning() |>
