@@ -17,8 +17,7 @@ test_that("extdata files are present", {
 test_that("read_text() gives expected output", {
   csv <- read_extdata("raman_hdpe.csv") |> read_text() |>
     expect_silent()
-  read_extdata("raman_hdpe.csv") |> read_text(share = tmp) |>
-    expect_message() |> expect_warning()
+
 
   dtf <- read_extdata("raman_hdpe.csv") |> read_text(method = "fread") |>
     expect_silent()
@@ -43,8 +42,6 @@ test_that("read_asp() gives expected output", {
     expect_silent()
   read_extdata("raman_hdpe.csv") |> read_asp() |>
     expect_error()
-  read_extdata("ftir_ldpe_soil.asp") |> read_asp(share = tmp) |>
-    expect_message() |> expect_warning()
 
   expect_s3_class(asp, "OpenSpecy")
   expect_true(check_OpenSpecy(asp))
@@ -62,9 +59,6 @@ test_that("read_spa() gives expected output", {
     read_spa() |> expect_silent()
   read_extdata("raman_hdpe.csv") |> read_spa() |>
     expect_error()
-  read_extdata("ftir_polyethylene_reflectance_adjustment_not_working.spa") |>
-    read_spa(share = tmp) |>
-    expect_message() |> expect_warning()
 
   expect_s3_class(spa, "OpenSpecy")
   expect_true(check_OpenSpecy(spa))
@@ -101,8 +95,7 @@ test_that("read_spc() gives expected output", {
     expect_silent()
   read_extdata("raman_hdpe.csv") |> read_spc() |>
     expect_error()
-  read_extdata("raman_atacamit.spc") |> read_spc(share = tmp) |>
-    expect_message() |> expect_warning()
+
 
   expect_s3_class(spc, "OpenSpecy")
   expect_true(check_OpenSpecy(spc))
